@@ -106,6 +106,7 @@ class Connection(object):
         host = self.options.get('host')
         port = self.options.get('port')
         raw_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        raw_socket.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
         raw_socket.connect((host, port))
 
         ssl_options = self.options.get('ssl')
@@ -130,7 +131,7 @@ class Connection(object):
         return self.socket
 
     def ssl(self):
-        return self.socket is not None and isinstance(ssl.SSLSocket, self.socket)
+        return self.socket is not None and isinstance(self.socket, ssl.SSLSocket)
 
     def opened(self):
         return (self.socket is not None
@@ -214,6 +215,8 @@ class Connection(object):
             #if hasattr(message, 'rows'):
             #    self.cursor.rowcount = message.rows
             pass
+        elif isinstance(message, messages.EmptyQueryResponse):
+            pass
         elif isinstance(message, messages.CopyInResponse):
             pass
         else:
